

from c7n.query import QueryResourceManager
from c7n.manager import resources


@resources.register('iam-group')
class Group(QueryResourceManager):

    resource_type = 'aws.iam.group'


@resources.register('iam-role')
class Role(QueryResourceManager):

    resource_type = 'aws.iam.role'


@resources.register('iam-user')
class User(QueryResourceManager):

    resource_type = 'aws.iam.user'


@resources.register('iam-policy')
class Policy(QueryResourceManager):

    resource_type = 'aws.iam.policy'


@resources.register('iam-profile')
class InstanceProfile(QueryResourceManager):

    resource_type = 'aws.iam.instance-profile'


@resources.register('server-cert')
class ServerCerficate(QueryResourceManager):

    resource_type = 'aws.iam.server-certificate'






from c7n.query import QueryResourceManager
from c7n.manager import resources


@resources.register('vpc')
class Vpc(QueryResourceManager):

    resource_type = 'aws.ec2.vpc'


@resources.register('subnet')
class Subnet(QueryResourceManager):

    resource_type = 'aws.ec2.subnet'


@resources.register('security-group')
class SecurityGroup(QueryResourceManager):

    resource_type = 'aws.ec2.security-group'


@resources.register('route-table')
class RouteTable(QueryResourceManager):

    resource_type = 'aws.ec2.route-table'


@resources.register('peering-connection')
class PeeringConnection(QueryResourceManager):

    resource_type = 'aws.ec2.vpc-peer-connection'


@resources.register('network-acl')
class NetworkAcl(QueryResourceManager):

    resource_type = 'aws.ec2.network-acl'


@resources.register('network-addr')
class Address(QueryResourceManager):

    resource_type = 'aws.ec2.address'


@resources.register('customer-gateway')
class CustomerGateway(QueryResourceManager):

    resource_type = 'aws.ec2.customer-gateway'


@resources.register('internet-gateway')
class InternetGateway(QueryResourceManager):

    class Meta(object):

        service = 'ec2'
        type = 'internet-gateway'
        enum_spec = ('describe_internet_gateways', 'InternetGateways', None)
        name = id = 'InternetGatewayId'
        filter_name = 'InternetGatewayIds'
        filter_type = 'list'
        dimension = None
        date = None

    resource_type = Meta





from c7n.query import QueryResourceManager
from c7n.manager import resources


@resources.register('hostedzone')
class HostedZone(QueryResourceManager):

    resource_type = 'aws.route53.hostedzone'


@resources.register('hostedzone')
class HealthCheck(QueryResourceManager):

    resource_type = 'aws.route53.healthcheck'





from c7n.query import QueryResourceManager
from c7n.manager import resources


@resources.register('cache-cluster')
class CacheCluster(QueryResourceManager):

    resource_type = 'aws.elasticache.Cluster'


@resources.register('cache-subnet-group')
class ClusterSubnetGroup(QueryResourceManager):

    resource_type = 'aws.elasticache.subnet-group'


@resources.register('cache-snapshot')
class CacheSnapshot(QueryResourceManager):

    resource_type = 'aws.elasticache.Snapshot'
